@@ -204,6 +204,7 @@ loadGenes<-function(fpkmFile,
 	write("Writing geneData table",stderr())
 	#dbWriteTable(dbConn,'geneData',as.data.frame(genemelt[,c(1:2,5,3,4,6)]),row.names=F,append=T)
 	insert_SQL<-'INSERT INTO geneData VALUES(:tracking_id,:sample_name,:fpkm,:conf_hi,:conf_lo,:status)'
+	#write(insert_SQL,stderr())
 	bulk_insert(dbConn,insert_SQL,genemelt[,c(1:2,5,3,4,6)])
 
 	#######
@@ -224,12 +225,14 @@ loadGenes<-function(fpkmFile,
 
 			write("Writing geneExpDiffData table",stderr())
 			diffCols<-c(1,5:14)
-
+			colnames(diff)[colnames(diff)=="log2.fold_change."]<-"log2_fold_change" # Not sure why this is the only place this is screwy...
+			
 			#debugging
 			#write(colnames(diff[,diffCols]),stderr())
 
 			#dbWriteTable(dbConn,'geneExpDiffData',diff[,diffCols],row.names=F,append=T)
-			insert_SQL<-"INSERT INTO geneExpDiffData VALUES(:test_id,:sample_1,:sample_2,:status,:value_1,:value_2,?,:test_stat,:p_value,:q_value,:significant)"
+
+			insert_SQL<-"INSERT INTO geneExpDiffData VALUES(:test_id,:sample_1,:sample_2,:status,:value_1,:value_2,:log2_fold_change,:test_stat,:p_value,:q_value,:significant)"
 			bulk_insert(dbConn,insert_SQL,diff[,diffCols])
 		}else{
 			write(paste("No records found in", diffFile),stderr())
@@ -1759,7 +1762,8 @@ getSamplesFromColnames<-function(fpkmDF){
 
 populateSampleTable<-function(samples,dbConn){
 	samples<-make.db.names(dbConn,samples,unique=FALSE)
-	samples<-data.frame(index=c(1:length(samples)),sample_name=samples)
+	samples<-data.frame(sample_index=c(1:length(samples)),sample_name=samples)
+	#print(samples)
 	dbWriteTable(dbConn,'samples',samples,row.names=F,append=T)
 }
 
@@ -1950,6 +1954,7 @@ readCufflinks<-function(dir = getwd(),
 		stop("Must provide a dbConn connection")
 
 	write("Reading GTF file",stderr())
+
 	gr<-import(gtfFile)
 	gr<-as(gr,"data.frame")
 	#gr$genome<-genomebuild
@@ -2014,7 +2019,9 @@ readCufflinks<-function(dir = getwd(),
 	tmpS <- split(tmp, values(tmp)$transcript_id)
 	if(verbose) message('Attempting to create the splicings data.frame')
 	splicings <- data.frame(
+
 			tx_id=rep(1:length(tmpS), elementNROWS(tmpS)),
+
 			exon_rank=as.integer(values(unlist(tmpS))$exon_number),
 			exon_chrom=as.character(seqnames(unlist(tmpS))),
 			exon_strand=as.character(strand(unlist(tmpS))),
@@ -2033,7 +2040,9 @@ readCufflinks<-function(dir = getwd(),
 
 	#create the db
 	if (verbose) message("Creating TranscriptDb")
+
 	tmpdb <- makeTxDb(transcripts, splicings, genes=genes)
+
 	if (verbose) message("Use saveFeatures() to save the database to a file")
 	return(tmpdb)
 
