@@ -764,11 +764,11 @@ setMethod("getSig",signature(object="CuffSet"),.getSig)
 	sig$testResult<-0
 	sig$testResult[sig$q_value<=alpha]<-1
 	
-	fieldsNeeded<-c('gene_id','testName','testResult')
+	fieldsNeeded<-c(slot(object,level)@idField,'testName','testResult')
 	sig<-sig[,fieldsNeeded]
 	
 	#recast
-	sig.table<-acast(sig,gene_id~testName,value='testResult')
+	sig.table<-acast(sig,as.formula(paste(slot(object,level)@idField,"~testName")),value='testResult')
 	
 	#remove genes that do not reject null in any test
 	sig.table<-sig.table[rowSums(sig.table,na.rm=T)>0,]
